using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win;

namespace DevscoveryPerformanceDemo
{
    public partial class Form1 : Form
    {
        long dtAppLoadBefore;
        public Form1(long dtBef)
        {
            dtAppLoadBefore = dtBef;
            InitializeComponent();
        }

        DataTable gridData = null;

        private void Form1_Load(object sender, EventArgs e)
        {

            this.ultraGrid1.InitializeLayout += new InitializeLayoutEventHandler(ultraGrid1_InitializeLayout);
            this.ultraGrid1.InitializeRow += new InitializeRowEventHandler(ultraGrid1_InitializeRow);
            this.ultraDataSource1.CellDataRequested += new Infragistics.Win.UltraWinDataSource.CellDataRequestedEventHandler(ultraDataSource1_CellDataRequested);

            gridData = this.generateDataTable(100000, 10);

            long dtBefore = DateTime.Now.Ticks;

            this.ultraDataSource1.Rows.SetCount(gridData.Rows.Count);
            this.ultraGrid1.DataSource = this.ultraDataSource1;

            //this.ultraGrid1.DataSource = gridData;
           

            long dtAfter = DateTime.Now.Ticks;

            long diff = dtAfter - dtBefore;

            this.label1.Text = "Grid Binding Time : " + TimeSpan.FromTicks(diff);
            
        }

        void ultraGrid1_InitializeRow(object sender, InitializeRowEventArgs e)
        {

            int thirdColumnCellValue = int.Parse(e.Row.Cells[3].Value.ToString());

            if ( (thirdColumnCellValue > 50) && (thirdColumnCellValue < 100000))
                e.Row.Cells[3].Appearance.BackColor = Color.Red;
        }

        private void ultraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            // LoadOnDemand will create grid rows as they are scrolled into view. This helps load
            // times if you have a lot of records in the datasource.
            // 
            e.Layout.LoadStyle = LoadStyle.LoadOnDemand;

            // By default the UltraGrid syncrhonizes its active row with the currency manager so other
            // controls bound to the same datasource can syncrhonize their active row (current item)
            // with the UltraGrid's active row and also the other way around. Your application may not
            // be making any use of such currency manager syncrhonization. For example, you may have only
            // one grid bound to the same datasource and thus there is no need to syncrhonize with the
            // currency manager. In that case you can disable this feature. This typically results in
            // more performant row navigation using up/down arrow key, especially in hierarchical situation.
            //
            this.ultraGrid1.SyncWithCurrencyManager = false;

            // Setting the CellDisplayStyle can have significant impact on the rendering/scrolling performance 
            // of the UltraGrid. This property indicates whether to embedd an embeddable ui element inside each 
            // cell or to render the value directly. The bahavior is typically the same unless you are using 
            // creation filter or draw filter to manipulate embeddable ui element hierarchy. Note that when 
            // editing a cell, the embeddable ui element will be used and therefore the editing behavior will 
            // be the same.
            //
            //foreach (UltraGridBand band in e.Layout.Bands)
            //{
            //    foreach (UltraGridColumn column in band.Columns)
            //    {
            //        // For string data types, typically formatting or applying editor data filters is not
            //        // necessary. Typically you simply want to draw the underlying cell value as it is.
            //        // For other types, you may want to apply formatting and if you are using editor data
            //        // filter, apply the data filter as well. Use FormattedText for those cases.
            //        //
            //        if (typeof(string) == column.DataType)
            //            column.CellDisplayStyle = CellDisplayStyle.PlainText;
            //        else
            //            column.CellDisplayStyle = CellDisplayStyle.FormattedText;
            //    }
            //}

            // If your grid is using the same back color for the cells as rows (which are the default
            // UltraGrid settings), then you can prevent cells from drawing the background color
            // since the rows are going to draw it. Setting the CellAppearance's BackColor to
            // Transparent will prevent them from drawing any backround. Note that this will not
            // prevent you from setting appearances on individual cells. Individual cell appearance
            // settings will still be honored.
            //
            e.Layout.Override.CellAppearance.BackColor = Color.Transparent;

            // You can take this one step further. If the UltraGrid's background color is also
            // the same as the row backcolor then you can prevent the rows from drawing the
            // back color. Note that this will not prevent you from setting appearances on individual 
            // rows. Individual row appearance settings will still be honored.
            //
            e.Layout.Override.RowAppearance.BackColor = Color.Transparent;

            // By default the UltraGrid repaints cells as the mouse enters or leaves the cells.
            // It does this so custom hot-track cell drawing can be easily accomplished using
            // a ui element creation filter or draw filter. Typically this does not pose a
            // performance problem however you may still want to disable this behavior in case
            // repainting of cells as mouse moves over the grid is undesirable.
            //
            e.Layout.CellHottrackInvalidationStyle = CellHottrackInvalidationStyle.OnlyIfHottrackAppearance;

            //Conditional Formatting on the Third Column
            e.Layout.Bands[0].Columns[3].ValueBasedAppearance = new customConditionalFormatting();

        }

        void ultraDataSource1_CellDataRequested(object sender, Infragistics.Win.UltraWinDataSource.CellDataRequestedEventArgs e)
        {
            e.Data = gridData.Rows[e.Row.Index][e.Column.Index];

            System.Diagnostics.Debug.WriteLine(" Data Fetching : " + e.Data);
            e.CacheData = true;
        }

        private DataTable generateDataTable(int rows, int cols)
        {
            this.label4.Text = "DataTable Size : " + rows + " X " + cols;

            long dataTableBefore = DateTime.Now.Ticks;

            DataTable dt = new DataTable();

            for (int i = 0; i < cols; i++)
            {
                dt.Columns.Add("Column " + i, typeof(string));
                this.ultraDataSource1.Band.Columns.Add("Column " + i, typeof(string));
            }

            for(int i = 0 ; i < rows ; i++)
            {
                DataRow dr = dt.NewRow();
                for (int j = 0; j < cols; j++)
                    dr[j] = (i + 1) * (j + 1);

                dt.Rows.Add(dr);
            }


            long dataTableAfter = DateTime.Now.Ticks;
            long Difference = dataTableAfter - dataTableBefore;
            this.label2.Text = "DataTable Generate Time : " + TimeSpan.FromTicks(Difference);

            return dt;

        }

        private void Form1_Activated(object sender, EventArgs e)
        {
            long dtAppLoadAfter = DateTime.Now.Ticks;

            long diff = dtAppLoadAfter - dtAppLoadBefore;

            this.label3.Text = "Application Load Time : " + TimeSpan.FromTicks(diff);
        }

    }

    public class customConditionalFormatting : IValueAppearance
    {
        #region IValueAppearance Members

        public event EventHandler PropertyChanged;

        public void ResolveAppearance(ref AppearanceData appData, ref AppearancePropFlags flags, object dataValue, IConditionContextProvider context)
        {
            int value = int.Parse(dataValue.ToString());

            if (value > 50 && value < 100000)
                appData.BackColor = Color.Blue;
        }

        #endregion

        #region ICloneable Members

        public object Clone()
        {
            throw new Exception("The method or operation is not implemented.");
        }

        #endregion
    }
}