using System.Diagnostics;
using Microsoft.VisualBasic;
using System;
using System.Data;
using System.Collections;
using System.IO;
using System.Text;
using System.Windows.Forms;

namespace Project.Support
{
	//'' -----------------------------------------------------------------------------
	//'' Project	 : Project.UI
	//'' Class	 : Project.UI.ErrorManager
	//''
	//'' -----------------------------------------------------------------------------
	//'' <summary>
	//'' This Class is responsible for Logging any and all Application Errors to
	//'' a custom logging system. Most of the times, it will be to a local file,
	//'' and this class is alot smaller than the MS Application Blocks equivalent.
	//'' </summary>
	//'' <remarks>
	//'' </remarks>
	//'' <history>
	//'' 	[ntense99]	11/23/2004	Created
	//'' </history>
	//'' -----------------------------------------------------------------------------
	
	
	public sealed class ErrorManager
	{
		public ErrorManager() {
			//static
		}
		public static string LogException(Exception ex)
		{
			return LogException(ex, null);
		}
		public static string LogException(Exception ex, string AdditionalInfo)
		{
			StringBuilder s = new StringBuilder();
			StreamWriter sWriter = null;
			
			try
			{
				sWriter = new StreamWriter(Config.ErrorLog, true);
				
				s.Append("\n");
				
				s.Append(DateTime.Now.ToLongDateString());
				
				s.Append("\n");
				
				if (!Convert.ToBoolean( AdditionalInfo == null))
				{
					s.Append("[");
					
					s.Append(AdditionalInfo);
					s.Append("]");
					s.Append("\n");
				}
				
				s.Append("[Error Message]");
				
				s.Append("\n");
				s.Append(ex.Message);
				
				s.Append("\n");
				s.Append("[Stack Trace]");
				
				s.Append("\n");
				s.Append(ex.StackTrace);
				
				s.Append("\n");
				s.Append("---------------------------------------------------------------------");
				
				s.Append("\n");
				sWriter.WriteLine(s.ToString());
				
				return s.ToString();
				
			}
			catch (Exception objException)
			{
				MessageBox.Show(objException.StackTrace, "Can't you even code the exception logger correctly???", MessageBoxButtons.OK, MessageBoxIcon.Error);
				
			}
			finally
			{
				sWriter.Flush();
				sWriter.Close();
				
				s = null;
				sWriter = null;
			}
			
			
			return "";
		}
		
		
	}
	
}
