using System.Diagnostics;
using Microsoft.VisualBasic;
using System;
using System.Data;
using System.Collections;

namespace Project.Support
{
	//'' -----------------------------------------------------------------------------
	//'' Project	 : Project.EventManager
	//'' Class	 : EventManager
	//''
	//'' -----------------------------------------------------------------------------
	//'' <summary>
	//'' This class handles ALL events that need to be published and raised from
	//'' ANY part of the application. Each event can be turned ON or OFF
	//'' </summary>
	//'' <remarks>
	//'' </remarks>
	//'' <history>
	//'' 	[ntense99]	11/23/2004	Created
	//'' </history>
	//'' -----------------------------------------------------------------------------
	public class EventManager
	{
		public EventManager() {
		}
		
		#region " Application Preferences Changed "
		
		//-----------------------------------------------------------------------------
		// This event is responsible for notifying the application whenever any
		// configuration has changed. In order to raise the event, you should
		// call the Event Raising method onApplicationPreferenceChanged. Any
		// Class that needs to be notified of any particular configuration change
		// should subscribe to the ApplicationPreferenceChanged event.
		// To Use the event, you will need to check the e.Preference to see what
		// Preference changed then check the e.Value for the new Value of the pref.
		//-----------------------------------------------------------------------------
		public  delegate void ApplicationPreferenceChangedEventHandler(object sender, ApplicationPreferenceChangedEventArgs e);
		
		private static ApplicationPreferenceChangedEventHandler ApplicationPreferenceChangedEvent;
		
		public static event ApplicationPreferenceChangedEventHandler ApplicationPreferenceChanged
		{
			add
			{
				Delegate.Combine(ApplicationPreferenceChangedEvent, value);
			}
			remove
			{
				Delegate.Remove(ApplicationPreferenceChangedEvent, value);
			}
		}
		
		public static void onApplicationPreferenceChanged (object sender, ApplicationPreferenceChangedEventArgs e)
		{
			if (_fireApplicationPreferenceChanged == false)	return;

			if (ApplicationPreferenceChangedEvent != null)ApplicationPreferenceChangedEvent(sender, e);
		}
		private static bool _fireApplicationPreferenceChanged = true;
		public static bool FireApplicationPreferenceChangedEvent
		{
			get
			{
				return _fireApplicationPreferenceChanged;
			}
			set
			{
				_fireApplicationPreferenceChanged = value;
			}
		}
		
		#endregion
		
	}
	
	
	#region " Application Preferences Changed "
	
	public class ApplicationPreferenceChangedEventArgs : EventArgs
	{
		public string Preference;
		public object Value;
		public ApplicationPreferenceChangedEventArgs(string thePreference, object theValue) {
			Preference = "";
			Value = null;
			
			this.Preference = thePreference;
			this.Value = theValue;
		}
	}
	
	#endregion
	
}
