using System.Diagnostics;
using Microsoft.VisualBasic;
using System;
using System.Data;
using System.Drawing;
using System.Windows.Forms;
using System.Collections;
using System.Reflection;
//using System.Windows.Forms;

namespace Project.UI
{
	//'' -----------------------------------------------------------------------------
	//'' Project	 : Project.FormsManager
	//'' Class	 : FormsManager
	//''
	//'' -----------------------------------------------------------------------------
	//'' <summary>
	//'' This class is responsible for launching and loading forms. A form can be
	//'' launched as an MDI Child, Modal, have a single instance, or multi instances.
	//'' </summary>
	//'' <remarks>
	//'' </remarks>
	//'' <history>
	//'' 	[ntense99]	11/23/2004	Created
	//'' </history>
	//'' -----------------------------------------------------------------------------
	
	public class FormsManager
	{
		public FormsManager() {
		}
		
		//-----------------------------------------------------------------------------
		// Loads a Form as an MDI Child.
		// Requires the Fully Qualified Form Name of the Form that we want to launch,
		// Requires the Unique Form Key that will be assigned to the Form Tag,
		// Requires the actual MDI Parent Form that will contain this new one,
		// Requires the option to ensire Single Instance, otherwise we can get
		// multiple form instances loaded.
		//-----------------------------------------------------------------------------
		public static Form LoadMDIForm(string FullyQualifiedFormName, string UniqueFormKey, Form MDIparent, bool EnsureSingleMDIChildInstance)
		{
			
			Form objForm = GetMDIForm(FullyQualifiedFormName, UniqueFormKey, MDIparent, EnsureSingleMDIChildInstance);
			
			objForm.MdiParent = MDIparent;
			if (objForm.Visible == false)
			{
				objForm.Show();
			}
			objForm.Activate();
			
			return objForm;
		}
		
		//-----------------------------------------------------------------------------
		// Returns an actual Form that you can use as you wish.
		// Requires the Fully Qualified Form Name of the Form that we want to launch,
		// Requires the Unique Form Key that will be assigned to the Form Tag,
		// Requires the actual MDI Parent Form that will contain this new one,
		// Requires the option to ensure Single Instance, otherwise we can get
		// multiple form instances loaded.
		//-----------------------------------------------------------------------------
		public static Form GetMDIForm(string FullyQualifiedFormName, string UniqueFormKey, Form MDIparent, bool EnsureSingleMDIChildInstance)
		{
			Form objForm = null;
			bool blnIsFound = false;
			
			if (EnsureSingleMDIChildInstance == true)
			{
				
				foreach (Form tempLoopVar_objForm in MDIparent.MdiChildren)
				{
					objForm = tempLoopVar_objForm;
					if (FullyQualifiedFormName == MDIparent.GetType().Namespace + "." + Information.TypeName(objForm) && System.Convert.ToString(objForm.Tag)== UniqueFormKey)
					{
						blnIsFound = true;
						break;
					}
				}
				
			}
			
			if (blnIsFound == false)
			{
				objForm = GetFormFromAsm(FullyQualifiedFormName);
				objForm.Tag = UniqueFormKey;
			}
			
			return objForm;
		}
		
		//-----------------------------------------------------------------------------
		// Returns a form that can be added to a Control Container
		//-----------------------------------------------------------------------------
		public static Form GetFormForControlContainer(string FullyQualifiedFormName, string UniqueFormKey)
		{
			Form objForm = GetFormFromAsm(FullyQualifiedFormName);
			objForm.Tag = UniqueFormKey;
			objForm.Dock = DockStyle.Fill;
			objForm.TopMost = false;
			objForm.FormBorderStyle = FormBorderStyle.None;
			return objForm;
		}
		
		//-----------------------------------------------------------------------------
		// Returns a form that is loaded from the executing Assembly using Reflection
		//-----------------------------------------------------------------------------
		public static Form GetFormFromAsm(string FullyQualifiedFormName)
		{
			Assembly objAsm = @Assembly.LoadFrom(@Assembly.GetExecutingAssembly().CodeBase);
			Type objFormType = objAsm.GetType(FullyQualifiedFormName);
			object objFormActivator = Activator.CreateInstance(objFormType);
			if (objFormActivator == null)
			{
				throw (new ApplicationException("Form: " + FullyQualifiedFormName + " could not be loaded. Please check the Namespace and Form Name and Try Again"));
			}
			return ((Form)(objFormActivator));
		}
		
	}
	
}
